@@ -440,6 +440,9 @@ class TestCGImageProperties(TestCase):
         # New definition in Xcode 10.14 SDK
         self.assertIsInstance(Quartz.kCGImagePropertyPrimaryImage, str)
 
+        # New definition in Xcode 12.5 SDK
+        self.assertIsInstance(Quartz.kCGImagePropertyPNGTransparency, str)
+
     @min_os_level("10.13.4")
     def testConstants10_13_4(self):
         self.assertIsInstance(Quartz.kCGImagePropertyIPTCExtAboutCvTerm, str)
@@ -821,8 +824,8 @@ class TestCGImageProperties(TestCase):
             Quartz.kCGImagePropertyExifSourceExposureTimesOfCompositeImage, str
         )
 
-    @min_os_level("10.16")
-    def testConstants10_16(self):
+    @min_os_level("11.0")
+    def testConstants11_0(self):
         self.assertIsInstance(Quartz.kCGImagePropertyWebPDictionary, str)
 
         self.assertIsInstance(Quartz.kCGImagePropertyWebPLoopCount, str)
@@ -838,3 +841,22 @@ class TestCGImageProperties(TestCase):
             Quartz.kCGImageAuxiliaryDataTypeSemanticSegmentationGlassesMatte, str
         )
         self.assertIsInstance(Quartz.kCGImageAuxiliaryDataTypeHDRGainMap, str)
+        self.assertIsInstance(
+            Quartz.kCGImageAuxiliaryDataTypeSemanticSegmentationSkyMatte, str
+        )
+
+    @min_os_level("12.0")
+    def testConstants12_0(self):
+        self.assertIsInstance(Quartz.kCGImagePropertyImageIndex, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroups, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupIndex, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupType, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupTypeStereoPair, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupTypeAlternate, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImagesAlternate, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImageIndexLeft, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImageIndexRight, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImageIsLeftImage, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImageIsRightImage, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyGroupImageIsAlternateImage, str)
+        self.assertIsInstance(Quartz.kCGImagePropertyPNGPixelsAspectRatio, str)
